#include <gio/gio.h>

#if defined (__ELF__) && ( __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 6))
# define SECTION __attribute__ ((section (".gresource.gresource"), aligned (sizeof(void *) > 8 ? sizeof(void *) : 8)))
#else
# define SECTION
#endif

static const SECTION union { const guint8 data[18125]; const double alignment; void * const ptr;}  gresource_resource_data = {
  "\107\126\141\162\151\141\156\164\000\000\000\000\000\000\000\000"
  "\030\000\000\000\254\000\000\000\000\000\000\050\005\000\000\000"
  "\000\000\000\000\002\000\000\000\003\000\000\000\003\000\000\000"
  "\004\000\000\000\113\120\220\013\001\000\000\000\254\000\000\000"
  "\004\000\114\000\260\000\000\000\264\000\000\000\324\265\002\000"
  "\377\377\377\377\264\000\000\000\001\000\114\000\270\000\000\000"
  "\274\000\000\000\075\370\304\171\003\000\000\000\274\000\000\000"
  "\021\000\166\000\320\000\000\000\243\106\000\000\050\361\365\216"
  "\004\000\000\000\243\106\000\000\025\000\114\000\270\106\000\000"
  "\274\106\000\000\326\374\147\005\000\000\000\000\274\106\000\000"
  "\014\000\114\000\310\106\000\000\314\106\000\000\157\162\147\057"
  "\004\000\000\000\057\000\000\000\000\000\000\000\156\155\055\160"
  "\160\164\160\055\144\151\141\154\157\147\056\165\151\000\000\000"
  "\303\105\000\000\000\000\000\000\074\077\170\155\154\040\166\145"
  "\162\163\151\157\156\075\042\061\056\060\042\040\145\156\143\157"
  "\144\151\156\147\075\042\125\124\106\055\070\042\077\076\012\074"
  "\041\055\055\040\107\145\156\145\162\141\164\145\144\040\167\151"
  "\164\150\040\147\154\141\144\145\040\063\056\061\070\056\063\040"
  "\055\055\076\012\074\151\156\164\145\162\146\141\143\145\076\074"
  "\162\145\161\165\151\162\145\163\040\154\151\142\075\042\147\164"
  "\153\053\042\040\166\145\162\163\151\157\156\075\042\063\056\064"
  "\042\057\076\074\157\142\152\145\143\164\040\143\154\141\163\163"
  "\075\042\107\164\153\101\144\152\165\163\164\155\145\156\164\042"
  "\040\151\144\075\042\141\144\152\165\163\164\155\145\156\164\061"
  "\042\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\165\160\160\145\162\042\076\066\065\065\063\065\074\057"
  "\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\163\164\145\160\137\151\156"
  "\143\162\145\155\145\156\164\042\076\061\074\057\160\162\157\160"
  "\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\160\141\147\145\137\151\156\143\162\145\155"
  "\145\156\164\042\076\061\060\074\057\160\162\157\160\145\162\164"
  "\171\076\074\057\157\142\152\145\143\164\076\074\157\142\152\145"
  "\143\164\040\143\154\141\163\163\075\042\107\164\153\114\151\163"
  "\164\123\164\157\162\145\042\040\151\144\075\042\155\157\144\145"
  "\154\061\042\076\074\143\157\154\165\155\156\163\076\074\041\055"
  "\055\040\143\157\154\165\155\156\055\156\141\155\145\040\147\143"
  "\150\141\162\141\162\162\141\171\040\055\055\076\074\143\157\154"
  "\165\155\156\040\164\171\160\145\075\042\147\143\150\141\162\141"
  "\162\162\141\171\042\057\076\074\057\143\157\154\165\155\156\163"
  "\076\074\144\141\164\141\076\074\162\157\167\076\074\143\157\154"
  "\040\151\144\075\042\060\042\040\164\162\141\156\163\154\141\164"
  "\141\142\154\145\075\042\171\145\163\042\076\104\145\146\141\165"
  "\154\164\074\057\143\157\154\076\074\057\162\157\167\076\074\057"
  "\144\141\164\141\076\074\057\157\142\152\145\143\164\076\074\157"
  "\142\152\145\143\164\040\143\154\141\163\163\075\042\107\164\153"
  "\104\151\141\154\157\147\042\040\151\144\075\042\160\160\164\160"
  "\055\141\144\166\141\156\143\145\144\055\144\151\141\154\157\147"
  "\042\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\143\141\156\137\146\157\143\165\163\042\076\106\141\154"
  "\163\145\074\057\160\162\157\160\145\162\164\171\076\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\164\151\164"
  "\154\145\042\040\164\162\141\156\163\154\141\164\141\142\154\145"
  "\075\042\171\145\163\042\076\120\120\124\120\040\101\144\166\141"
  "\156\143\145\144\040\117\160\164\151\157\156\163\074\057\160\162"
  "\157\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\155\157\144\141\154\042\076\124\162"
  "\165\145\074\057\160\162\157\160\145\162\164\171\076\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\144\145\163"
  "\164\162\157\171\137\167\151\164\150\137\160\141\162\145\156\164"
  "\042\076\124\162\165\145\074\057\160\162\157\160\145\162\164\171"
  "\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\151\143\157\156\137\156\141\155\145\042\076\163\164\157\143"
  "\153\055\160\162\145\146\145\162\145\156\143\145\163\074\057\160"
  "\162\157\160\145\162\164\171\076\074\141\143\164\151\157\156\055"
  "\167\151\144\147\145\164\163\076\074\141\143\164\151\157\156\055"
  "\167\151\144\147\145\164\040\162\145\163\160\157\156\163\145\075"
  "\042\055\066\042\076\143\141\156\143\145\154\137\142\165\164\164"
  "\157\156\074\057\141\143\164\151\157\156\055\167\151\144\147\145"
  "\164\076\074\141\143\164\151\157\156\055\167\151\144\147\145\164"
  "\040\162\145\163\160\157\156\163\145\075\042\055\065\042\076\141"
  "\160\160\154\171\137\142\165\164\164\157\156\074\057\141\143\164"
  "\151\157\156\055\167\151\144\147\145\164\076\074\057\141\143\164"
  "\151\157\156\055\167\151\144\147\145\164\163\076\074\143\150\151"
  "\154\144\040\164\171\160\145\075\042\164\151\164\154\145\142\141"
  "\162\042\076\074\157\142\152\145\143\164\040\143\154\141\163\163"
  "\075\042\107\164\153\110\145\141\144\145\162\102\141\162\042\076"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\166\151\163\151\142\154\145\042\076\124\162\165\145\074\057\160"
  "\162\157\160\145\162\164\171\076\074\160\162\157\160\145\162\164"
  "\171\040\156\141\155\145\075\042\143\141\156\055\146\157\143\165"
  "\163\042\076\106\141\154\163\145\074\057\160\162\157\160\145\162"
  "\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\163\150\157\167\055\143\154\157\163\145\055\142\165"
  "\164\164\157\156\042\076\106\141\154\163\145\074\057\160\162\157"
  "\160\145\162\164\171\076\074\143\150\151\154\144\040\164\171\160"
  "\145\075\042\164\151\164\154\145\042\076\074\157\142\152\145\143"
  "\164\040\143\154\141\163\163\075\042\107\164\153\114\141\142\145"
  "\154\042\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\166\151\163\151\142\154\145\042\076\124\162\165\145"
  "\074\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\143\141\156\055\146"
  "\157\143\165\163\042\076\106\141\154\163\145\074\057\160\162\157"
  "\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\154\141\142\145\154\042\040\164\162\141"
  "\156\163\154\141\164\141\142\154\145\075\042\171\145\163\042\076"
  "\101\144\166\141\156\143\145\144\040\120\162\157\160\145\162\164"
  "\151\145\163\074\057\160\162\157\160\145\162\164\171\076\074\163"
  "\164\171\154\145\076\074\143\154\141\163\163\040\156\141\155\145"
  "\075\042\164\151\164\154\145\042\057\076\074\057\163\164\171\154"
  "\145\076\074\057\157\142\152\145\143\164\076\074\057\143\150\151"
  "\154\144\076\074\143\150\151\154\144\076\074\157\142\152\145\143"
  "\164\040\143\154\141\163\163\075\042\107\164\153\102\165\164\164"
  "\157\156\042\040\151\144\075\042\143\141\156\143\145\154\137\142"
  "\165\164\164\157\156\042\076\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\154\141\142\145\154\042\040\164\162"
  "\141\156\163\154\141\164\141\142\154\145\075\042\171\145\163\042"
  "\076\137\103\141\156\143\145\154\074\057\160\162\157\160\145\162"
  "\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\166\151\163\151\142\154\145\042\076\124\162\165\145"
  "\074\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\143\141\156\055\146"
  "\157\143\165\163\042\076\124\162\165\145\074\057\160\162\157\160"
  "\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\165\163\145\055\165\156\144\145\162\154\151"
  "\156\145\042\076\124\162\165\145\074\057\160\162\157\160\145\162"
  "\164\171\076\074\057\157\142\152\145\143\164\076\074\057\143\150"
  "\151\154\144\076\074\143\150\151\154\144\076\074\157\142\152\145"
  "\143\164\040\143\154\141\163\163\075\042\107\164\153\102\165\164"
  "\164\157\156\042\040\151\144\075\042\141\160\160\154\171\137\142"
  "\165\164\164\157\156\042\076\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\154\141\142\145\154\042\040\164\162"
  "\141\156\163\154\141\164\141\142\154\145\075\042\171\145\163\042"
  "\076\137\101\160\160\154\171\074\057\160\162\157\160\145\162\164"
  "\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\166\151\163\151\142\154\145\042\076\124\162\165\145\074"
  "\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\143\141\156\055\146\157"
  "\143\165\163\042\076\124\162\165\145\074\057\160\162\157\160\145"
  "\162\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\162\145\143\145\151\166\145\163\055\144\145\146"
  "\141\165\154\164\042\076\124\162\165\145\074\057\160\162\157\160"
  "\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\165\163\145\055\165\156\144\145\162\154\151"
  "\156\145\042\076\124\162\165\145\074\057\160\162\157\160\145\162"
  "\164\171\076\074\163\164\171\154\145\076\074\143\154\141\163\163"
  "\040\156\141\155\145\075\042\144\145\146\141\165\154\164\042\057"
  "\076\074\143\154\141\163\163\040\156\141\155\145\075\042\163\165"
  "\147\147\145\163\164\145\144\055\141\143\164\151\157\156\042\057"
  "\076\074\057\163\164\171\154\145\076\074\057\157\142\152\145\143"
  "\164\076\074\160\141\143\153\151\156\147\076\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\160\141\143\153\055"
  "\164\171\160\145\042\076\145\156\144\074\057\160\162\157\160\145"
  "\162\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\160\157\163\151\164\151\157\156\042\076\061\074"
  "\057\160\162\157\160\145\162\164\171\076\074\057\160\141\143\153"
  "\151\156\147\076\074\057\143\150\151\154\144\076\074\057\157\142"
  "\152\145\143\164\076\074\057\143\150\151\154\144\076\074\143\150"
  "\151\154\144\040\151\156\164\145\162\156\141\154\055\143\150\151"
  "\154\144\075\042\166\142\157\170\042\076\074\157\142\152\145\143"
  "\164\040\143\154\141\163\163\075\042\107\164\153\102\157\170\042"
  "\040\151\144\075\042\144\151\141\154\157\147\055\166\142\157\170"
  "\063\042\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\166\151\163\151\142\154\145\042\076\124\162\165\145"
  "\074\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\143\141\156\137\146"
  "\157\143\165\163\042\076\106\141\154\163\145\074\057\160\162\157"
  "\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\157\162\151\145\156\164\141\164\151\157"
  "\156\042\076\166\145\162\164\151\143\141\154\074\057\160\162\157"
  "\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\155\141\162\147\151\156\055\163\164\141"
  "\162\164\042\076\062\064\074\057\160\162\157\160\145\162\164\171"
  "\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\155\141\162\147\151\156\055\145\156\144\042\076\062\064\074"
  "\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\155\141\162\147\151\156"
  "\055\164\157\160\042\076\062\064\074\057\160\162\157\160\145\162"
  "\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\155\141\162\147\151\156\055\142\157\164\164\157\155"
  "\042\076\062\064\074\057\160\162\157\160\145\162\164\171\076\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\163"
  "\160\141\143\151\156\147\042\076\061\066\074\057\160\162\157\160"
  "\145\162\164\171\076\074\143\150\151\154\144\040\151\156\164\145"
  "\162\156\141\154\055\143\150\151\154\144\075\042\141\143\164\151"
  "\157\156\137\141\162\145\141\042\076\074\157\142\152\145\143\164"
  "\040\143\154\141\163\163\075\042\107\164\153\102\157\170\042\040"
  "\151\144\075\042\144\151\141\154\157\147\055\141\143\164\151\157"
  "\156\137\141\162\145\141\061\042\076\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\166\151\163\151\142\154\145"
  "\042\076\124\162\165\145\074\057\160\162\157\160\145\162\164\171"
  "\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\143\141\156\137\146\157\143\165\163\042\076\106\141\154\163"
  "\145\074\057\160\162\157\160\145\162\164\171\076\074\143\150\151"
  "\154\144\076\074\160\154\141\143\145\150\157\154\144\145\162\057"
  "\076\074\057\143\150\151\154\144\076\074\143\150\151\154\144\076"
  "\074\160\154\141\143\145\150\157\154\144\145\162\057\076\074\057"
  "\143\150\151\154\144\076\074\057\157\142\152\145\143\164\076\074"
  "\160\141\143\153\151\156\147\076\074\160\162\157\160\145\162\164"
  "\171\040\156\141\155\145\075\042\145\170\160\141\156\144\042\076"
  "\106\141\154\163\145\074\057\160\162\157\160\145\162\164\171\076"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\146\151\154\154\042\076\106\141\154\163\145\074\057\160\162\157"
  "\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\160\141\143\153\137\164\171\160\145\042"
  "\076\145\156\144\074\057\160\162\157\160\145\162\164\171\076\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\160"
  "\157\163\151\164\151\157\156\042\076\060\074\057\160\162\157\160"
  "\145\162\164\171\076\074\057\160\141\143\153\151\156\147\076\074"
  "\057\143\150\151\154\144\076\074\143\150\151\154\144\076\074\157"
  "\142\152\145\143\164\040\143\154\141\163\163\075\042\107\164\153"
  "\102\157\170\042\040\151\144\075\042\120\160\160\120\141\147\145"
  "\042\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\166\151\163\151\142\154\145\042\076\124\162\165\145\074"
  "\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\143\141\156\137\146\157"
  "\143\165\163\042\076\106\141\154\163\145\074\057\160\162\157\160"
  "\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\157\162\151\145\156\164\141\164\151\157\156"
  "\042\076\166\145\162\164\151\143\141\154\074\057\160\162\157\160"
  "\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\163\160\141\143\151\156\147\042\076\066\074"
  "\057\160\162\157\160\145\162\164\171\076\074\143\150\151\154\144"
  "\076\074\157\142\152\145\143\164\040\143\154\141\163\163\075\042"
  "\107\164\153\114\141\142\145\154\042\040\151\144\075\042\154\141"
  "\142\145\154\062\070\042\076\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\166\151\163\151\142\154\145\042\076"
  "\124\162\165\145\074\057\160\162\157\160\145\162\164\171\076\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\143"
  "\141\156\137\146\157\143\165\163\042\076\106\141\154\163\145\074"
  "\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\170\141\154\151\147\156"
  "\042\076\060\074\057\160\162\157\160\145\162\164\171\076\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\154\141"
  "\142\145\154\042\040\164\162\141\156\163\154\141\164\141\142\154"
  "\145\075\042\171\145\163\042\076\101\165\164\150\145\156\164\151"
  "\143\141\164\151\157\156\074\057\160\162\157\160\145\162\164\171"
  "\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\155\141\162\147\151\156\137\142\157\164\164\157\155\042\076"
  "\066\074\057\160\162\157\160\145\162\164\171\076\074\141\164\164"
  "\162\151\142\165\164\145\163\076\074\141\164\164\162\151\142\165"
  "\164\145\040\156\141\155\145\075\042\167\145\151\147\150\164\042"
  "\040\166\141\154\165\145\075\042\142\157\154\144\042\057\076\074"
  "\057\141\164\164\162\151\142\165\164\145\163\076\074\057\157\142"
  "\152\145\143\164\076\074\057\143\150\151\154\144\076\074\143\150"
  "\151\154\144\076\074\157\142\152\145\143\164\040\143\154\141\163"
  "\163\075\042\107\164\153\114\141\142\145\154\042\040\151\144\075"
  "\042\141\165\164\150\137\155\145\164\150\157\144\163\137\154\141"
  "\142\145\154\042\076\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\166\151\163\151\142\154\145\042\076\124\162"
  "\165\145\074\057\160\162\157\160\145\162\164\171\076\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\143\141\156"
  "\137\146\157\143\165\163\042\076\106\141\154\163\145\074\057\160"
  "\162\157\160\145\162\164\171\076\074\160\162\157\160\145\162\164"
  "\171\040\156\141\155\145\075\042\170\141\154\151\147\156\042\076"
  "\060\074\057\160\162\157\160\145\162\164\171\076\074\160\162\157"
  "\160\145\162\164\171\040\156\141\155\145\075\042\154\141\142\145"
  "\154\042\040\164\162\141\156\163\154\141\164\141\142\154\145\075"
  "\042\171\145\163\042\076\101\154\154\157\167\040\164\150\145\040"
  "\146\157\154\154\157\167\151\156\147\040\141\165\164\150\145\156"
  "\164\151\143\141\164\151\157\156\040\155\145\164\150\157\144\163"
  "\072\074\057\160\162\157\160\145\162\164\171\076\074\057\157\142"
  "\152\145\143\164\076\074\057\143\150\151\154\144\076\074\143\150"
  "\151\154\144\076\074\157\142\152\145\143\164\040\143\154\141\163"
  "\163\075\042\107\164\153\123\143\162\157\154\154\145\144\127\151"
  "\156\144\157\167\042\040\151\144\075\042\163\143\162\157\154\154"
  "\145\144\167\151\156\144\157\167\061\042\076\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\166\151\163\151\142"
  "\154\145\042\076\124\162\165\145\074\057\160\162\157\160\145\162"
  "\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\143\141\156\137\146\157\143\165\163\042\076\124\162"
  "\165\145\074\057\160\162\157\160\145\162\164\171\076\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\150\163\143"
  "\162\157\154\154\142\141\162\137\160\157\154\151\143\171\042\076"
  "\156\145\166\145\162\074\057\160\162\157\160\145\162\164\171\076"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\155\151\156\137\143\157\156\164\145\156\164\137\150\145\151\147"
  "\150\164\042\076\070\060\074\057\160\162\157\160\145\162\164\171"
  "\076\074\143\150\151\154\144\076\074\157\142\152\145\143\164\040"
  "\143\154\141\163\163\075\042\107\164\153\124\162\145\145\126\151"
  "\145\167\042\040\151\144\075\042\160\160\160\137\141\165\164\150"
  "\137\155\145\164\150\157\144\163\042\076\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\166\151\163\151\142\154"
  "\145\042\076\124\162\165\145\074\057\160\162\157\160\145\162\164"
  "\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\143\141\156\137\146\157\143\165\163\042\076\124\162\165"
  "\145\074\057\160\162\157\160\145\162\164\171\076\074\160\162\157"
  "\160\145\162\164\171\040\156\141\155\145\075\042\164\157\157\154"
  "\164\151\160\137\164\145\170\164\042\040\164\162\141\156\163\154"
  "\141\164\141\142\154\145\075\042\171\145\163\042\076\101\154\154"
  "\157\167\057\144\151\163\141\142\154\145\040\141\165\164\150\145"
  "\156\164\151\143\141\164\151\157\156\040\155\145\164\150\157\144"
  "\163\056\012\143\157\156\146\151\147\072\040\162\145\146\165\163"
  "\145\055\160\141\160\054\040\162\145\146\165\163\145\055\143\150"
  "\141\160\054\040\162\145\146\165\163\145\055\155\163\143\150\141"
  "\160\054\040\162\145\146\165\163\145\055\155\163\143\150\141\160"
  "\055\166\062\054\040\162\145\146\165\163\145\055\145\141\160\074"
  "\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\150\145\141\144\145\162"
  "\163\137\166\151\163\151\142\154\145\042\076\106\141\154\163\145"
  "\074\057\160\162\157\160\145\162\164\171\076\074\143\150\151\154"
  "\144\040\151\156\164\145\162\156\141\154\055\143\150\151\154\144"
  "\075\042\163\145\154\145\143\164\151\157\156\042\076\074\157\142"
  "\152\145\143\164\040\143\154\141\163\163\075\042\107\164\153\124"
  "\162\145\145\123\145\154\145\143\164\151\157\156\042\040\151\144"
  "\075\042\164\162\145\145\166\151\145\167\055\163\145\154\145\143"
  "\164\151\157\156\061\042\057\076\074\057\143\150\151\154\144\076"
  "\074\057\157\142\152\145\143\164\076\074\057\143\150\151\154\144"
  "\076\074\057\157\142\152\145\143\164\076\074\057\143\150\151\154"
  "\144\076\074\143\150\151\154\144\076\074\157\142\152\145\143\164"
  "\040\143\154\141\163\163\075\042\107\164\153\114\141\142\145\154"
  "\042\040\151\144\075\042\154\141\142\145\154\062\071\042\076\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\166"
  "\151\163\151\142\154\145\042\076\124\162\165\145\074\057\160\162"
  "\157\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\143\141\156\137\146\157\143\165\163"
  "\042\076\106\141\154\163\145\074\057\160\162\157\160\145\162\164"
  "\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\170\141\154\151\147\156\042\076\060\074\057\160\162\157"
  "\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\154\141\142\145\154\042\040\164\162\141"
  "\156\163\154\141\164\141\142\154\145\075\042\171\145\163\042\076"
  "\123\145\143\165\162\151\164\171\040\141\156\144\040\103\157\155"
  "\160\162\145\163\163\151\157\156\074\057\160\162\157\160\145\162"
  "\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\155\141\162\147\151\156\137\164\157\160\042\076\061"
  "\062\074\057\160\162\157\160\145\162\164\171\076\074\160\162\157"
  "\160\145\162\164\171\040\156\141\155\145\075\042\155\141\162\147"
  "\151\156\137\142\157\164\164\157\155\042\076\066\074\057\160\162"
  "\157\160\145\162\164\171\076\074\141\164\164\162\151\142\165\164"
  "\145\163\076\074\141\164\164\162\151\142\165\164\145\040\156\141"
  "\155\145\075\042\167\145\151\147\150\164\042\040\166\141\154\165"
  "\145\075\042\142\157\154\144\042\057\076\074\057\141\164\164\162"
  "\151\142\165\164\145\163\076\074\057\157\142\152\145\143\164\076"
  "\074\057\143\150\151\154\144\076\074\143\150\151\154\144\076\074"
  "\157\142\152\145\143\164\040\143\154\141\163\163\075\042\107\164"
  "\153\103\150\145\143\153\102\165\164\164\157\156\042\040\151\144"
  "\075\042\160\160\160\137\165\163\145\137\155\160\160\145\042\076"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\154\141\142\145\154\042\040\164\162\141\156\163\154\141\164\141"
  "\142\154\145\075\042\171\145\163\042\076\125\163\145\040\137\120"
  "\157\151\156\164\055\164\157\055\120\157\151\156\164\040\145\156"
  "\143\162\171\160\164\151\157\156\040\050\115\120\120\105\051\074"
  "\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\166\151\163\151\142\154"
  "\145\042\076\124\162\165\145\074\057\160\162\157\160\145\162\164"
  "\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\143\141\156\137\146\157\143\165\163\042\076\124\162\165"
  "\145\074\057\160\162\157\160\145\162\164\171\076\074\160\162\157"
  "\160\145\162\164\171\040\156\141\155\145\075\042\162\145\143\145"
  "\151\166\145\163\137\144\145\146\141\165\154\164\042\076\106\141"
  "\154\163\145\074\057\160\162\157\160\145\162\164\171\076\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\164\157"
  "\157\154\164\151\160\137\164\145\170\164\042\040\164\162\141\156"
  "\163\154\141\164\141\142\154\145\075\042\171\145\163\042\076\116"
  "\157\164\145\072\040\115\120\120\105\040\145\156\143\162\171\160"
  "\164\151\157\156\040\151\163\040\157\156\154\171\040\141\166\141"
  "\151\154\141\142\154\145\040\167\151\164\150\040\115\123\103\110"
  "\101\120\040\141\165\164\150\145\156\164\151\143\141\164\151\157"
  "\156\040\155\145\164\150\157\144\163\056\040\124\157\040\145\156"
  "\141\142\154\145\040\164\150\151\163\040\143\150\145\143\153\142"
  "\157\170\054\040\163\145\154\145\143\164\040\157\156\145\040\157"
  "\162\040\155\157\162\145\040\157\146\040\164\150\145\040\115\123"
  "\103\110\101\120\040\141\165\164\150\145\156\164\151\143\141\164"
  "\151\157\156\040\155\145\164\150\157\144\163\072\040\115\123\103"
  "\110\101\120\040\157\162\040\115\123\103\110\101\120\166\062\056"
  "\074\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\165\163\145\137\165"
  "\156\144\145\162\154\151\156\145\042\076\124\162\165\145\074\057"
  "\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\144\162\141\167\137\151\156"
  "\144\151\143\141\164\157\162\042\076\124\162\165\145\074\057\160"
  "\162\157\160\145\162\164\171\076\074\057\157\142\152\145\143\164"
  "\076\074\057\143\150\151\154\144\076\074\143\150\151\154\144\076"
  "\074\157\142\152\145\143\164\040\143\154\141\163\163\075\042\107"
  "\164\153\102\157\170\042\076\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\166\151\163\151\142\154\145\042\076"
  "\124\162\165\145\074\057\160\162\157\160\145\162\164\171\076\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\157"
  "\162\151\145\156\164\141\164\151\157\156\042\076\150\157\162\151"
  "\172\157\156\164\141\154\074\057\160\162\157\160\145\162\164\171"
  "\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\163\160\141\143\151\156\147\042\076\066\074\057\160\162\157"
  "\160\145\162\164\171\076\074\143\150\151\154\144\076\074\157\142"
  "\152\145\143\164\040\143\154\141\163\163\075\042\107\164\153\114"
  "\141\142\145\154\042\040\151\144\075\042\160\160\160\137\155\160"
  "\160\145\137\163\145\143\165\162\151\164\171\137\154\141\142\145"
  "\154\042\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\166\151\163\151\142\154\145\042\076\124\162\165\145"
  "\074\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\143\141\156\137\146"
  "\157\143\165\163\042\076\106\141\154\163\145\074\057\160\162\157"
  "\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\170\141\154\151\147\156\042\076\060\074"
  "\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\154\141\142\145\154\042"
  "\040\164\162\141\156\163\154\141\164\141\142\154\145\075\042\171"
  "\145\163\042\076\137\123\145\143\165\162\151\164\171\072\074\057"
  "\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\165\163\145\137\165\156\144"
  "\145\162\154\151\156\145\042\076\124\162\165\145\074\057\160\162"
  "\157\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\155\156\145\155\157\156\151\143\137"
  "\167\151\144\147\145\164\042\076\160\160\160\137\155\160\160\145"
  "\137\163\145\143\165\162\151\164\171\137\143\157\155\142\157\074"
  "\057\160\162\157\160\145\162\164\171\076\074\057\157\142\152\145"
  "\143\164\076\074\057\143\150\151\154\144\076\074\143\150\151\154"
  "\144\076\074\157\142\152\145\143\164\040\143\154\141\163\163\075"
  "\042\107\164\153\103\157\155\142\157\102\157\170\042\040\151\144"
  "\075\042\160\160\160\137\155\160\160\145\137\163\145\143\165\162"
  "\151\164\171\137\143\157\155\142\157\042\076\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\166\151\163\151\142"
  "\154\145\042\076\124\162\165\145\074\057\160\162\157\160\145\162"
  "\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\143\141\156\137\146\157\143\165\163\042\076\106\141"
  "\154\163\145\074\057\160\162\157\160\145\162\164\171\076\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\164\157"
  "\157\154\164\151\160\137\164\145\170\164\042\040\164\162\141\156"
  "\163\154\141\164\141\142\154\145\075\042\171\145\163\042\076\122"
  "\145\161\165\151\162\145\040\164\150\145\040\165\163\145\040\157"
  "\146\040\115\120\120\105\054\040\167\151\164\150\040\064\060\057"
  "\061\062\070\055\142\151\164\040\145\156\143\162\171\160\164\151"
  "\157\156\040\157\162\040\141\154\154\056\012\040\040\040\040\143"
  "\157\156\146\151\147\072\040\162\145\161\165\151\162\145\055\155"
  "\160\160\145\054\040\162\145\161\165\151\162\145\055\155\160\160"
  "\145\055\061\062\070\040\157\162\040\162\145\161\165\151\162\145"
  "\055\155\160\160\145\055\064\060\074\057\160\162\157\160\145\162"
  "\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\155\157\144\145\154\042\076\155\157\144\145\154\061"
  "\074\057\160\162\157\160\145\162\164\171\076\074\143\150\151\154"
  "\144\076\074\157\142\152\145\143\164\040\143\154\141\163\163\075"
  "\042\107\164\153\103\145\154\154\122\145\156\144\145\162\145\162"
  "\124\145\170\164\042\040\151\144\075\042\162\145\156\144\145\162"
  "\145\162\061\042\057\076\074\141\164\164\162\151\142\165\164\145"
  "\163\076\074\141\164\164\162\151\142\165\164\145\040\156\141\155"
  "\145\075\042\164\145\170\164\042\076\060\074\057\141\164\164\162"
  "\151\142\165\164\145\076\074\057\141\164\164\162\151\142\165\164"
  "\145\163\076\074\057\143\150\151\154\144\076\074\057\157\142\152"
  "\145\143\164\076\074\057\143\150\151\154\144\076\074\057\157\142"
  "\152\145\143\164\076\074\057\143\150\151\154\144\076\074\143\150"
  "\151\154\144\076\074\157\142\152\145\143\164\040\143\154\141\163"
  "\163\075\042\107\164\153\103\150\145\143\153\102\165\164\164\157"
  "\156\042\040\151\144\075\042\160\160\160\137\141\154\154\157\167"
  "\137\163\164\141\164\145\146\165\154\137\155\160\160\145\042\076"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\154\141\142\145\154\042\040\164\162\141\156\163\154\141\164\141"
  "\142\154\145\075\042\171\145\163\042\076\101\154\154\157\167\040"
  "\163\164\137\141\164\145\146\165\154\040\145\156\143\162\171\160"
  "\164\151\157\156\074\057\160\162\157\160\145\162\164\171\076\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\166"
  "\151\163\151\142\154\145\042\076\124\162\165\145\074\057\160\162"
  "\157\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\143\141\156\137\146\157\143\165\163"
  "\042\076\124\162\165\145\074\057\160\162\157\160\145\162\164\171"
  "\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\162\145\143\145\151\166\145\163\137\144\145\146\141\165\154"
  "\164\042\076\106\141\154\163\145\074\057\160\162\157\160\145\162"
  "\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\164\157\157\154\164\151\160\137\164\145\170\164\042"
  "\040\164\162\141\156\163\154\141\164\141\142\154\145\075\042\171"
  "\145\163\042\076\101\154\154\157\167\040\115\120\120\105\040\164"
  "\157\040\165\163\145\040\163\164\141\164\145\146\165\154\040\155"
  "\157\144\145\056\040\123\164\141\164\145\154\145\163\163\040\155"
  "\157\144\145\040\151\163\040\163\164\151\154\154\040\141\164\164"
  "\145\155\160\164\145\144\040\146\151\162\163\164\056\012\143\157"
  "\156\146\151\147\072\040\155\160\160\145\055\163\164\141\164\145"
  "\146\165\154\040\050\167\150\145\156\040\143\150\145\143\153\145"
  "\144\051\074\057\160\162\157\160\145\162\164\171\076\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\165\163\145"
  "\137\165\156\144\145\162\154\151\156\145\042\076\124\162\165\145"
  "\074\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\144\162\141\167\137"
  "\151\156\144\151\143\141\164\157\162\042\076\124\162\165\145\074"
  "\057\160\162\157\160\145\162\164\171\076\074\057\157\142\152\145"
  "\143\164\076\074\057\143\150\151\154\144\076\074\143\150\151\154"
  "\144\076\074\157\142\152\145\143\164\040\143\154\141\163\163\075"
  "\042\107\164\153\103\150\145\143\153\102\165\164\164\157\156\042"
  "\040\151\144\075\042\160\160\160\137\141\154\154\157\167\137\142"
  "\163\144\143\157\155\160\042\076\074\160\162\157\160\145\162\164"
  "\171\040\156\141\155\145\075\042\154\141\142\145\154\042\040\164"
  "\162\141\156\163\154\141\164\141\142\154\145\075\042\171\145\163"
  "\042\076\101\154\154\157\167\040\137\102\123\104\040\144\141\164"
  "\141\040\143\157\155\160\162\145\163\163\151\157\156\074\057\160"
  "\162\157\160\145\162\164\171\076\074\160\162\157\160\145\162\164"
  "\171\040\156\141\155\145\075\042\166\151\163\151\142\154\145\042"
  "\076\124\162\165\145\074\057\160\162\157\160\145\162\164\171\076"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\143\141\156\137\146\157\143\165\163\042\076\124\162\165\145\074"
  "\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\162\145\143\145\151\166"
  "\145\163\137\144\145\146\141\165\154\164\042\076\106\141\154\163"
  "\145\074\057\160\162\157\160\145\162\164\171\076\074\160\162\157"
  "\160\145\162\164\171\040\156\141\155\145\075\042\164\157\157\154"
  "\164\151\160\137\164\145\170\164\042\040\164\162\141\156\163\154"
  "\141\164\141\142\154\145\075\042\171\145\163\042\076\101\154\154"
  "\157\167\057\144\151\163\141\142\154\145\040\102\123\104\055\103"
  "\157\155\160\162\145\163\163\040\143\157\155\160\162\145\163\163"
  "\151\157\156\056\012\143\157\156\146\151\147\072\040\156\157\142"
  "\163\144\143\157\155\160\040\050\167\150\145\156\040\165\156\143"
  "\150\145\143\153\145\144\051\074\057\160\162\157\160\145\162\164"
  "\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\165\163\145\137\165\156\144\145\162\154\151\156\145\042"
  "\076\124\162\165\145\074\057\160\162\157\160\145\162\164\171\076"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\144\162\141\167\137\151\156\144\151\143\141\164\157\162\042\076"
  "\124\162\165\145\074\057\160\162\157\160\145\162\164\171\076\074"
  "\057\157\142\152\145\143\164\076\074\057\143\150\151\154\144\076"
  "\074\143\150\151\154\144\076\074\157\142\152\145\143\164\040\143"
  "\154\141\163\163\075\042\107\164\153\103\150\145\143\153\102\165"
  "\164\164\157\156\042\040\151\144\075\042\160\160\160\137\141\154"
  "\154\157\167\137\144\145\146\154\141\164\145\042\076\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\154\141\142"
  "\145\154\042\040\164\162\141\156\163\154\141\164\141\142\154\145"
  "\075\042\171\145\163\042\076\101\154\154\157\167\040\137\104\145"
  "\146\154\141\164\145\040\144\141\164\141\040\143\157\155\160\162"
  "\145\163\163\151\157\156\074\057\160\162\157\160\145\162\164\171"
  "\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\166\151\163\151\142\154\145\042\076\124\162\165\145\074\057"
  "\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\143\141\156\137\146\157\143"
  "\165\163\042\076\124\162\165\145\074\057\160\162\157\160\145\162"
  "\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\162\145\143\145\151\166\145\163\137\144\145\146\141"
  "\165\154\164\042\076\106\141\154\163\145\074\057\160\162\157\160"
  "\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\164\157\157\154\164\151\160\137\164\145\170"
  "\164\042\040\164\162\141\156\163\154\141\164\141\142\154\145\075"
  "\042\171\145\163\042\076\101\154\154\157\167\057\144\151\163\141"
  "\142\154\145\040\104\145\146\154\141\164\145\040\143\157\155\160"
  "\162\145\163\163\151\157\156\056\012\143\157\156\146\151\147\072"
  "\040\156\157\144\145\146\154\141\164\145\040\050\167\150\145\156"
  "\040\165\156\143\150\145\143\153\145\144\051\074\057\160\162\157"
  "\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\165\163\145\137\165\156\144\145\162\154"
  "\151\156\145\042\076\124\162\165\145\074\057\160\162\157\160\145"
  "\162\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\144\162\141\167\137\151\156\144\151\143\141\164"
  "\157\162\042\076\124\162\165\145\074\057\160\162\157\160\145\162"
  "\164\171\076\074\057\157\142\152\145\143\164\076\074\057\143\150"
  "\151\154\144\076\074\143\150\151\154\144\076\074\157\142\152\145"
  "\143\164\040\143\154\141\163\163\075\042\107\164\153\103\150\145"
  "\143\153\102\165\164\164\157\156\042\040\151\144\075\042\160\160"
  "\160\137\165\163\145\166\152\042\076\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\154\141\142\145\154\042\040"
  "\164\162\141\156\163\154\141\164\141\142\154\145\075\042\171\145"
  "\163\042\076\125\163\145\040\124\103\120\040\137\150\145\141\144"
  "\145\162\040\143\157\155\160\162\145\163\163\151\157\156\074\057"
  "\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\166\151\163\151\142\154\145"
  "\042\076\124\162\165\145\074\057\160\162\157\160\145\162\164\171"
  "\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\143\141\156\137\146\157\143\165\163\042\076\124\162\165\145"
  "\074\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\162\145\143\145\151"
  "\166\145\163\137\144\145\146\141\165\154\164\042\076\106\141\154"
  "\163\145\074\057\160\162\157\160\145\162\164\171\076\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\164\157\157"
  "\154\164\151\160\137\164\145\170\164\042\040\164\162\141\156\163"
  "\154\141\164\141\142\154\145\075\042\171\145\163\042\076\101\154"
  "\154\157\167\057\144\151\163\141\142\154\145\040\126\141\156\040"
  "\112\141\143\157\142\163\157\156\040\163\164\171\154\145\040\124"
  "\103\120\057\111\120\040\150\145\141\144\145\162\040\143\157\155"
  "\160\162\145\163\163\151\157\156\040\151\156\040\142\157\164\150"
  "\040\164\150\145\040\164\162\141\156\163\155\151\164\040\141\156"
  "\144\040\164\150\145\040\162\145\143\145\151\166\145\040\144\151"
  "\162\145\143\164\151\157\156\163\056\012\143\157\156\146\151\147"
  "\072\040\156\157\166\152\040\050\167\150\145\156\040\165\156\143"
  "\150\145\143\153\145\144\051\074\057\160\162\157\160\145\162\164"
  "\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\165\163\145\137\165\156\144\145\162\154\151\156\145\042"
  "\076\124\162\165\145\074\057\160\162\157\160\145\162\164\171\076"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\144\162\141\167\137\151\156\144\151\143\141\164\157\162\042\076"
  "\124\162\165\145\074\057\160\162\157\160\145\162\164\171\076\074"
  "\057\157\142\152\145\143\164\076\074\057\143\150\151\154\144\076"
  "\074\143\150\151\154\144\076\074\157\142\152\145\143\164\040\143"
  "\154\141\163\163\075\042\107\164\153\114\141\142\145\154\042\040"
  "\151\144\075\042\154\141\142\145\154\063\062\042\076\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\166\151\163"
  "\151\142\154\145\042\076\124\162\165\145\074\057\160\162\157\160"
  "\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\143\141\156\137\146\157\143\165\163\042\076"
  "\106\141\154\163\145\074\057\160\162\157\160\145\162\164\171\076"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\170\141\154\151\147\156\042\076\060\074\057\160\162\157\160\145"
  "\162\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\154\141\142\145\154\042\040\164\162\141\156\163"
  "\154\141\164\141\142\154\145\075\042\171\145\163\042\076\115\151"
  "\163\143\074\057\160\162\157\160\145\162\164\171\076\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\155\141\162"
  "\147\151\156\137\164\157\160\042\076\061\062\074\057\160\162\157"
  "\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\155\141\162\147\151\156\137\142\157\164"
  "\164\157\155\042\076\066\074\057\160\162\157\160\145\162\164\171"
  "\076\074\141\164\164\162\151\142\165\164\145\163\076\074\141\164"
  "\164\162\151\142\165\164\145\040\156\141\155\145\075\042\167\145"
  "\151\147\150\164\042\040\166\141\154\165\145\075\042\142\157\154"
  "\144\042\057\076\074\057\141\164\164\162\151\142\165\164\145\163"
  "\076\074\057\157\142\152\145\143\164\076\074\057\143\150\151\154"
  "\144\076\074\143\150\151\154\144\076\074\157\142\152\145\143\164"
  "\040\143\154\141\163\163\075\042\107\164\153\103\150\145\143\153"
  "\102\165\164\164\157\156\042\040\151\144\075\042\160\160\160\137"
  "\163\145\156\144\137\145\143\150\157\137\160\141\143\153\145\164"
  "\163\042\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\154\141\142\145\154\042\040\164\162\141\156\163\154"
  "\141\164\141\142\154\145\075\042\171\145\163\042\076\123\145\156"
  "\144\040\120\120\120\040\137\145\143\150\157\040\160\141\143\153"
  "\145\164\163\074\057\160\162\157\160\145\162\164\171\076\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\166\151"
  "\163\151\142\154\145\042\076\124\162\165\145\074\057\160\162\157"
  "\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\143\141\156\137\146\157\143\165\163\042"
  "\076\124\162\165\145\074\057\160\162\157\160\145\162\164\171\076"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\162\145\143\145\151\166\145\163\137\144\145\146\141\165\154\164"
  "\042\076\106\141\154\163\145\074\057\160\162\157\160\145\162\164"
  "\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\164\157\157\154\164\151\160\137\164\145\170\164\042\040"
  "\164\162\141\156\163\154\141\164\141\142\154\145\075\042\171\145"
  "\163\042\076\123\145\156\144\040\114\103\120\040\145\143\150\157"
  "\055\162\145\161\165\145\163\164\163\040\164\157\040\146\151\156"
  "\144\040\157\165\164\040\167\150\145\164\150\145\162\040\160\145"
  "\145\162\040\151\163\040\141\154\151\166\145\056\012\143\157\156"
  "\146\151\147\072\040\154\143\160\055\145\143\150\157\055\146\141"
  "\151\154\165\162\145\040\141\156\144\040\154\143\160\055\145\143"
  "\150\157\055\151\156\164\145\162\166\141\154\074\057\160\162\157"
  "\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\165\163\145\137\165\156\144\145\162\154"
  "\151\156\145\042\076\124\162\165\145\074\057\160\162\157\160\145"
  "\162\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\144\162\141\167\137\151\156\144\151\143\141\164"
  "\157\162\042\076\124\162\165\145\074\057\160\162\157\160\145\162"
  "\164\171\076\074\057\157\142\152\145\143\164\076\074\057\143\150"
  "\151\154\144\076\074\143\150\151\154\144\076\074\157\142\152\145"
  "\143\164\040\143\154\141\163\163\075\042\107\164\153\102\157\170"
  "\042\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\166\151\163\151\142\154\145\042\076\124\162\165\145\074"
  "\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\157\162\151\145\156\164"
  "\141\164\151\157\156\042\076\150\157\162\151\172\157\156\164\141"
  "\154\074\057\160\162\157\160\145\162\164\171\076\074\160\162\157"
  "\160\145\162\164\171\040\156\141\155\145\075\042\163\160\141\143"
  "\151\156\147\042\076\066\074\057\160\162\157\160\145\162\164\171"
  "\076\074\143\150\151\154\144\076\074\157\142\152\145\143\164\040"
  "\143\154\141\163\163\075\042\107\164\153\103\150\145\143\153\102"
  "\165\164\164\157\156\042\040\151\144\075\042\160\160\160\137\165"
  "\156\151\164\137\143\150\145\143\153\142\165\164\164\157\156\042"
  "\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\154\141\142\145\154\042\040\164\162\141\156\163\154\141\164"
  "\141\142\154\145\075\042\171\145\163\042\076\125\163\145\040\143"
  "\165\163\164\157\155\040\137\165\156\151\164\040\156\165\155\142"
  "\145\162\072\074\057\160\162\157\160\145\162\164\171\076\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\166\151"
  "\163\151\142\154\145\042\076\124\162\165\145\074\057\160\162\157"
  "\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\143\141\156\137\146\157\143\165\163\042"
  "\076\124\162\165\145\074\057\160\162\157\160\145\162\164\171\076"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\162\145\143\145\151\166\145\163\137\144\145\146\141\165\154\164"
  "\042\076\106\141\154\163\145\074\057\160\162\157\160\145\162\164"
  "\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\164\157\157\154\164\151\160\137\164\145\170\164\042\040"
  "\164\162\141\156\163\154\141\164\141\142\154\145\075\042\171\145"
  "\163\042\076\105\156\141\142\154\145\040\143\165\163\164\157\155"
  "\040\151\156\144\145\170\040\146\157\162\040\160\160\160\046\154"
  "\164\073\156\046\147\164\073\040\144\145\166\151\143\145\040\156"
  "\141\155\145\056\012\040\040\040\040\143\157\156\146\151\147\072"
  "\040\165\156\151\164\040\046\154\164\073\156\046\147\164\073\074"
  "\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\165\163\145\137\165\156"
  "\144\145\162\154\151\156\145\042\076\124\162\165\145\074\057\160"
  "\162\157\160\145\162\164\171\076\074\160\162\157\160\145\162\164"
  "\171\040\156\141\155\145\075\042\144\162\141\167\137\151\156\144"
  "\151\143\141\164\157\162\042\076\124\162\165\145\074\057\160\162"
  "\157\160\145\162\164\171\076\074\057\157\142\152\145\143\164\076"
  "\074\057\143\150\151\154\144\076\074\143\150\151\154\144\076\074"
  "\157\142\152\145\143\164\040\143\154\141\163\163\075\042\107\164"
  "\153\123\160\151\156\102\165\164\164\157\156\042\040\151\144\075"
  "\042\160\160\160\137\165\156\151\164\137\163\160\151\156\142\165"
  "\164\164\157\156\042\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\166\151\163\151\142\154\145\042\076\124"
  "\162\165\145\074\057\160\162\157\160\145\162\164\171\076\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\143\141"
  "\156\137\146\157\143\165\163\042\076\124\162\165\145\074\057\160"
  "\162\157\160\145\162\164\171\076\074\160\162\157\160\145\162\164"
  "\171\040\156\141\155\145\075\042\164\157\157\154\164\151\160\137"
  "\164\145\170\164\042\040\164\162\141\156\163\154\141\164\141\142"
  "\154\145\075\042\171\145\163\042\076\105\156\141\142\154\145\040"
  "\143\165\163\164\157\155\040\151\156\144\145\170\040\146\157\162"
  "\040\160\160\160\046\154\164\073\156\046\147\164\073\040\144\145"
  "\166\151\143\145\040\156\141\155\145\056\012\040\040\040\040\143"
  "\157\156\146\151\147\072\040\165\156\151\164\040\046\154\164\073"
  "\156\046\147\164\073\074\057\160\162\157\160\145\162\164\171\076"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\141\144\152\165\163\164\155\145\156\164\042\076\141\144\152\165"
  "\163\164\155\145\156\164\061\074\057\160\162\157\160\145\162\164"
  "\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\143\154\151\155\142\137\162\141\164\145\042\076\061\074"
  "\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\156\165\155\145\162\151"
  "\143\042\076\124\162\165\145\074\057\160\162\157\160\145\162\164"
  "\171\076\074\057\157\142\152\145\143\164\076\074\057\143\150\151"
  "\154\144\076\074\057\157\142\152\145\143\164\076\074\057\143\150"
  "\151\154\144\076\074\057\157\142\152\145\143\164\076\074\160\141"
  "\143\153\151\156\147\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\145\170\160\141\156\144\042\076\106\141"
  "\154\163\145\074\057\160\162\157\160\145\162\164\171\076\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\146\151"
  "\154\154\042\076\124\162\165\145\074\057\160\162\157\160\145\162"
  "\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\160\157\163\151\164\151\157\156\042\076\061\074\057"
  "\160\162\157\160\145\162\164\171\076\074\057\160\141\143\153\151"
  "\156\147\076\074\057\143\150\151\154\144\076\074\057\157\142\152"
  "\145\143\164\076\074\057\143\150\151\154\144\076\074\057\157\142"
  "\152\145\143\164\076\074\157\142\152\145\143\164\040\143\154\141"
  "\163\163\075\042\107\164\153\114\151\163\164\123\164\157\162\145"
  "\042\040\151\144\075\042\155\157\144\145\154\062\042\076\074\143"
  "\157\154\165\155\156\163\076\074\041\055\055\040\143\157\154\165"
  "\155\156\055\156\141\155\145\040\147\143\150\141\162\141\162\162"
  "\141\171\040\055\055\076\074\143\157\154\165\155\156\040\164\171"
  "\160\145\075\042\147\143\150\141\162\141\162\162\141\171\042\057"
  "\076\074\057\143\157\154\165\155\156\163\076\074\144\141\164\141"
  "\076\074\162\157\167\076\074\143\157\154\040\151\144\075\042\060"
  "\042\076\040\074\057\143\157\154\076\074\057\162\157\167\076\074"
  "\057\144\141\164\141\076\074\057\157\142\152\145\143\164\076\074"
  "\157\142\152\145\143\164\040\143\154\141\163\163\075\042\107\164"
  "\153\107\162\151\144\042\040\151\144\075\042\160\160\164\160\055"
  "\166\142\157\170\042\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\166\151\163\151\142\154\145\042\076\124"
  "\162\165\145\074\057\160\162\157\160\145\162\164\171\076\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\162\157"
  "\167\137\163\160\141\143\151\156\147\042\076\066\074\057\160\162"
  "\157\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\143\157\154\165\155\156\137\163\160"
  "\141\143\151\156\147\042\076\066\074\057\160\162\157\160\145\162"
  "\164\171\076\074\143\150\151\154\144\076\074\157\142\152\145\143"
  "\164\040\143\154\141\163\163\075\042\107\164\153\114\141\142\145"
  "\154\042\040\151\144\075\042\154\141\142\145\154\062\062\042\076"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\166\151\163\151\142\154\145\042\076\124\162\165\145\074\057\160"
  "\162\157\160\145\162\164\171\076\074\160\162\157\160\145\162\164"
  "\171\040\156\141\155\145\075\042\143\141\156\137\146\157\143\165"
  "\163\042\076\106\141\154\163\145\074\057\160\162\157\160\145\162"
  "\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\170\141\154\151\147\156\042\076\060\074\057\160\162"
  "\157\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\155\141\162\147\151\156\137\142\157"
  "\164\164\157\155\042\076\066\074\057\160\162\157\160\145\162\164"
  "\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\154\141\142\145\154\042\040\164\162\141\156\163\154\141"
  "\164\141\142\154\145\075\042\171\145\163\042\076\107\145\156\145"
  "\162\141\154\074\057\160\162\157\160\145\162\164\171\076\074\141"
  "\164\164\162\151\142\165\164\145\163\076\074\141\164\164\162\151"
  "\142\165\164\145\040\156\141\155\145\075\042\167\145\151\147\150"
  "\164\042\040\166\141\154\165\145\075\042\142\157\154\144\042\057"
  "\076\074\057\141\164\164\162\151\142\165\164\145\163\076\074\057"
  "\157\142\152\145\143\164\076\074\160\141\143\153\151\156\147\076"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\154\145\146\164\137\141\164\164\141\143\150\042\076\060\074\057"
  "\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\164\157\160\137\141\164\164"
  "\141\143\150\042\076\060\074\057\160\162\157\160\145\162\164\171"
  "\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\167\151\144\164\150\042\076\062\074\057\160\162\157\160\145"
  "\162\164\171\076\074\057\160\141\143\153\151\156\147\076\074\057"
  "\143\150\151\154\144\076\074\143\150\151\154\144\076\074\157\142"
  "\152\145\143\164\040\143\154\141\163\163\075\042\107\164\153\114"
  "\141\142\145\154\042\040\151\144\075\042\154\141\142\145\154\062"
  "\063\042\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\166\151\163\151\142\154\145\042\076\124\162\165\145"
  "\074\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\143\141\156\137\146"
  "\157\143\165\163\042\076\106\141\154\163\145\074\057\160\162\157"
  "\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\170\141\154\151\147\156\042\076\061\074"
  "\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\154\141\142\145\154\042"
  "\040\164\162\141\156\163\154\141\164\141\142\154\145\075\042\171"
  "\145\163\042\076\137\107\141\164\145\167\141\171\074\057\160\162"
  "\157\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\165\163\145\137\165\156\144\145\162"
  "\154\151\156\145\042\076\124\162\165\145\074\057\160\162\157\160"
  "\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\155\156\145\155\157\156\151\143\137\167\151"
  "\144\147\145\164\042\076\147\141\164\145\167\141\171\137\145\156"
  "\164\162\171\074\057\160\162\157\160\145\162\164\171\076\074\057"
  "\157\142\152\145\143\164\076\074\160\141\143\153\151\156\147\076"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\154\145\146\164\137\141\164\164\141\143\150\042\076\060\074\057"
  "\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\164\157\160\137\141\164\164"
  "\141\143\150\042\076\061\074\057\160\162\157\160\145\162\164\171"
  "\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\167\151\144\164\150\042\076\061\074\057\160\162\157\160\145"
  "\162\164\171\076\074\057\160\141\143\153\151\156\147\076\074\057"
  "\143\150\151\154\144\076\074\143\150\151\154\144\076\074\157\142"
  "\152\145\143\164\040\143\154\141\163\163\075\042\107\164\153\105"
  "\156\164\162\171\042\040\151\144\075\042\147\141\164\145\167\141"
  "\171\137\145\156\164\162\171\042\076\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\166\151\163\151\142\154\145"
  "\042\076\124\162\165\145\074\057\160\162\157\160\145\162\164\171"
  "\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\143\141\156\137\146\157\143\165\163\042\076\124\162\165\145"
  "\074\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\164\157\157\154\164"
  "\151\160\137\164\145\170\164\042\040\164\162\141\156\163\154\141"
  "\164\141\142\154\145\075\042\171\145\163\042\076\120\120\124\120"
  "\040\163\145\162\166\145\162\040\111\120\040\157\162\040\156\141"
  "\155\145\056\012\143\157\156\146\151\147\072\040\164\150\145\040"
  "\146\151\162\163\164\040\160\141\162\141\155\145\164\145\162\040"
  "\157\146\040\160\160\164\160\074\057\160\162\157\160\145\162\164"
  "\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\150\145\170\160\141\156\144\042\076\124\162\165\145\074"
  "\057\160\162\157\160\145\162\164\171\076\074\057\157\142\152\145"
  "\143\164\076\074\160\141\143\153\151\156\147\076\074\160\162\157"
  "\160\145\162\164\171\040\156\141\155\145\075\042\154\145\146\164"
  "\137\141\164\164\141\143\150\042\076\061\074\057\160\162\157\160"
  "\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\164\157\160\137\141\164\164\141\143\150\042"
  "\076\061\074\057\160\162\157\160\145\162\164\171\076\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\167\151\144"
  "\164\150\042\076\061\074\057\160\162\157\160\145\162\164\171\076"
  "\074\057\160\141\143\153\151\156\147\076\074\057\143\150\151\154"
  "\144\076\074\143\150\151\154\144\076\074\157\142\152\145\143\164"
  "\040\143\154\141\163\163\075\042\107\164\153\114\141\142\145\154"
  "\042\040\151\144\075\042\154\141\142\145\154\062\065\042\076\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\166"
  "\151\163\151\142\154\145\042\076\124\162\165\145\074\057\160\162"
  "\157\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\143\141\156\137\146\157\143\165\163"
  "\042\076\106\141\154\163\145\074\057\160\162\157\160\145\162\164"
  "\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\170\141\154\151\147\156\042\076\060\074\057\160\162\157"
  "\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\155\141\162\147\151\156\137\164\157\160"
  "\042\076\061\062\074\057\160\162\157\160\145\162\164\171\076\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\155"
  "\141\162\147\151\156\137\142\157\164\164\157\155\042\076\066\074"
  "\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\154\141\142\145\154\042"
  "\040\164\162\141\156\163\154\141\164\141\142\154\145\075\042\171"
  "\145\163\042\076\117\160\164\151\157\156\141\154\074\057\160\162"
  "\157\160\145\162\164\171\076\074\141\164\164\162\151\142\165\164"
  "\145\163\076\074\141\164\164\162\151\142\165\164\145\040\156\141"
  "\155\145\075\042\167\145\151\147\150\164\042\040\166\141\154\165"
  "\145\075\042\142\157\154\144\042\057\076\074\057\141\164\164\162"
  "\151\142\165\164\145\163\076\074\057\157\142\152\145\143\164\076"
  "\074\160\141\143\153\151\156\147\076\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\154\145\146\164\137\141\164"
  "\164\141\143\150\042\076\060\074\057\160\162\157\160\145\162\164"
  "\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\164\157\160\137\141\164\164\141\143\150\042\076\062\074"
  "\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\167\151\144\164\150\042"
  "\076\062\074\057\160\162\157\160\145\162\164\171\076\074\057\160"
  "\141\143\153\151\156\147\076\074\057\143\150\151\154\144\076\074"
  "\143\150\151\154\144\076\074\157\142\152\145\143\164\040\143\154"
  "\141\163\163\075\042\107\164\153\114\141\142\145\154\042\040\151"
  "\144\075\042\154\141\142\145\154\062\066\042\076\074\160\162\157"
  "\160\145\162\164\171\040\156\141\155\145\075\042\166\151\163\151"
  "\142\154\145\042\076\124\162\165\145\074\057\160\162\157\160\145"
  "\162\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\143\141\156\137\146\157\143\165\163\042\076\106"
  "\141\154\163\145\074\057\160\162\157\160\145\162\164\171\076\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\170"
  "\141\154\151\147\156\042\076\061\074\057\160\162\157\160\145\162"
  "\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\154\141\142\145\154\042\040\164\162\141\156\163\154"
  "\141\164\141\142\154\145\075\042\171\145\163\042\076\125\163\145"
  "\162\040\156\141\155\145\074\057\160\162\157\160\145\162\164\171"
  "\076\074\057\157\142\152\145\143\164\076\074\160\141\143\153\151"
  "\156\147\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\154\145\146\164\137\141\164\164\141\143\150\042\076"
  "\060\074\057\160\162\157\160\145\162\164\171\076\074\160\162\157"
  "\160\145\162\164\171\040\156\141\155\145\075\042\164\157\160\137"
  "\141\164\164\141\143\150\042\076\063\074\057\160\162\157\160\145"
  "\162\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\167\151\144\164\150\042\076\061\074\057\160\162"
  "\157\160\145\162\164\171\076\074\057\160\141\143\153\151\156\147"
  "\076\074\057\143\150\151\154\144\076\074\143\150\151\154\144\076"
  "\074\157\142\152\145\143\164\040\143\154\141\163\163\075\042\107"
  "\164\153\105\156\164\162\171\042\040\151\144\075\042\165\163\145"
  "\162\137\145\156\164\162\171\042\076\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\166\151\163\151\142\154\145"
  "\042\076\124\162\165\145\074\057\160\162\157\160\145\162\164\171"
  "\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\143\141\156\137\146\157\143\165\163\042\076\124\162\165\145"
  "\074\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\164\157\157\154\164"
  "\151\160\137\164\145\170\164\042\040\164\162\141\156\163\154\141"
  "\164\141\142\154\145\075\042\171\145\163\042\076\123\145\164\040"
  "\164\150\145\040\156\141\155\145\040\165\163\145\144\040\146\157"
  "\162\040\141\165\164\150\145\156\164\151\143\141\164\151\156\147"
  "\040\164\150\145\040\154\157\143\141\154\040\163\171\163\164\145"
  "\155\040\164\157\040\164\150\145\040\160\145\145\162\040\164\157"
  "\040\046\154\164\073\156\141\155\145\046\147\164\073\056\012\143"
  "\157\156\146\151\147\072\040\165\163\145\162\040\046\154\164\073"
  "\156\141\155\145\046\147\164\073\074\057\160\162\157\160\145\162"
  "\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\150\145\170\160\141\156\144\042\076\124\162\165\145"
  "\074\057\160\162\157\160\145\162\164\171\076\074\057\157\142\152"
  "\145\143\164\076\074\160\141\143\153\151\156\147\076\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\154\145\146"
  "\164\137\141\164\164\141\143\150\042\076\061\074\057\160\162\157"
  "\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\164\157\160\137\141\164\164\141\143\150"
  "\042\076\063\074\057\160\162\157\160\145\162\164\171\076\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\167\151"
  "\144\164\150\042\076\061\074\057\160\162\157\160\145\162\164\171"
  "\076\074\057\160\141\143\153\151\156\147\076\074\057\143\150\151"
  "\154\144\076\074\143\150\151\154\144\076\074\157\142\152\145\143"
  "\164\040\143\154\141\163\163\075\042\107\164\153\114\141\142\145"
  "\154\042\040\151\144\075\042\154\141\142\145\154\062\042\076\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\166"
  "\151\163\151\142\154\145\042\076\124\162\165\145\074\057\160\162"
  "\157\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\143\141\156\137\146\157\143\165\163"
  "\042\076\106\141\154\163\145\074\057\160\162\157\160\145\162\164"
  "\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\170\141\154\151\147\156\042\076\061\074\057\160\162\157"
  "\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\154\141\142\145\154\042\040\164\162\141"
  "\156\163\154\141\164\141\142\154\145\075\042\171\145\163\042\076"
  "\120\141\163\163\167\157\162\144\074\057\160\162\157\160\145\162"
  "\164\171\076\074\057\157\142\152\145\143\164\076\074\160\141\143"
  "\153\151\156\147\076\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\154\145\146\164\137\141\164\164\141\143\150"
  "\042\076\060\074\057\160\162\157\160\145\162\164\171\076\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\164\157"
  "\160\137\141\164\164\141\143\150\042\076\064\074\057\160\162\157"
  "\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\167\151\144\164\150\042\076\061\074\057"
  "\160\162\157\160\145\162\164\171\076\074\057\160\141\143\153\151"
  "\156\147\076\074\057\143\150\151\154\144\076\074\143\150\151\154"
  "\144\076\074\157\142\152\145\143\164\040\143\154\141\163\163\075"
  "\042\107\164\153\105\156\164\162\171\042\040\151\144\075\042\165"
  "\163\145\162\137\160\141\163\163\167\157\162\144\137\145\156\164"
  "\162\171\042\076\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\166\151\163\151\142\154\145\042\076\124\162\165"
  "\145\074\057\160\162\157\160\145\162\164\171\076\074\160\162\157"
  "\160\145\162\164\171\040\156\141\155\145\075\042\143\141\156\137"
  "\146\157\143\165\163\042\076\124\162\165\145\074\057\160\162\157"
  "\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\164\157\157\154\164\151\160\137\164\145"
  "\170\164\042\040\164\162\141\156\163\154\141\164\141\142\154\145"
  "\075\042\171\145\163\042\076\120\141\163\163\167\157\162\144\040"
  "\160\141\163\163\145\144\040\164\157\040\120\120\124\120\040\167"
  "\150\145\156\040\160\162\157\155\160\164\145\144\040\146\157\162"
  "\040\151\164\056\074\057\160\162\157\160\145\162\164\171\076\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\150"
  "\145\170\160\141\156\144\042\076\124\162\165\145\074\057\160\162"
  "\157\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\166\151\163\151\142\151\154\151\164"
  "\171\042\076\106\141\154\163\145\074\057\160\162\157\160\145\162"
  "\164\171\076\074\057\157\142\152\145\143\164\076\074\160\141\143"
  "\153\151\156\147\076\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\154\145\146\164\137\141\164\164\141\143\150"
  "\042\076\061\074\057\160\162\157\160\145\162\164\171\076\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\164\157"
  "\160\137\141\164\164\141\143\150\042\076\064\074\057\160\162\157"
  "\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\167\151\144\164\150\042\076\061\074\057"
  "\160\162\157\160\145\162\164\171\076\074\057\160\141\143\153\151"
  "\156\147\076\074\057\143\150\151\154\144\076\074\143\150\151\154"
  "\144\076\074\157\142\152\145\143\164\040\143\154\141\163\163\075"
  "\042\107\164\153\103\150\145\143\153\102\165\164\164\157\156\042"
  "\040\151\144\075\042\163\150\157\167\137\160\141\163\163\167\157"
  "\162\144\163\137\143\150\145\143\153\142\165\164\164\157\156\042"
  "\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\154\141\142\145\154\042\040\164\162\141\156\163\154\141\164"
  "\141\142\154\145\075\042\171\145\163\042\076\123\150\157\167\040"
  "\160\141\163\163\167\157\162\144\074\057\160\162\157\160\145\162"
  "\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\166\151\163\151\142\154\145\042\076\124\162\165\145"
  "\074\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\143\141\156\137\146"
  "\157\143\165\163\042\076\124\162\165\145\074\057\160\162\157\160"
  "\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\162\145\143\145\151\166\145\163\137\144\145"
  "\146\141\165\154\164\042\076\106\141\154\163\145\074\057\160\162"
  "\157\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\144\162\141\167\137\151\156\144\151"
  "\143\141\164\157\162\042\076\124\162\165\145\074\057\160\162\157"
  "\160\145\162\164\171\076\074\057\157\142\152\145\143\164\076\074"
  "\160\141\143\153\151\156\147\076\074\160\162\157\160\145\162\164"
  "\171\040\156\141\155\145\075\042\154\145\146\164\137\141\164\164"
  "\141\143\150\042\076\061\074\057\160\162\157\160\145\162\164\171"
  "\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\164\157\160\137\141\164\164\141\143\150\042\076\065\074\057"
  "\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\167\151\144\164\150\042\076"
  "\061\074\057\160\162\157\160\145\162\164\171\076\074\057\160\141"
  "\143\153\151\156\147\076\074\057\143\150\151\154\144\076\074\143"
  "\150\151\154\144\076\074\157\142\152\145\143\164\040\143\154\141"
  "\163\163\075\042\107\164\153\114\141\142\145\154\042\040\151\144"
  "\075\042\154\141\142\145\154\062\067\042\076\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\166\151\163\151\142"
  "\154\145\042\076\124\162\165\145\074\057\160\162\157\160\145\162"
  "\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\143\141\156\137\146\157\143\165\163\042\076\106\141"
  "\154\163\145\074\057\160\162\157\160\145\162\164\171\076\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\170\141"
  "\154\151\147\156\042\076\061\074\057\160\162\157\160\145\162\164"
  "\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\154\141\142\145\154\042\040\164\162\141\156\163\154\141"
  "\164\141\142\154\145\075\042\171\145\163\042\076\116\124\040\104"
  "\157\155\141\151\156\074\057\160\162\157\160\145\162\164\171\076"
  "\074\057\157\142\152\145\143\164\076\074\160\141\143\153\151\156"
  "\147\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\154\145\146\164\137\141\164\164\141\143\150\042\076\060"
  "\074\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\164\157\160\137\141"
  "\164\164\141\143\150\042\076\066\074\057\160\162\157\160\145\162"
  "\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\167\151\144\164\150\042\076\061\074\057\160\162\157"
  "\160\145\162\164\171\076\074\057\160\141\143\153\151\156\147\076"
  "\074\057\143\150\151\154\144\076\074\143\150\151\154\144\076\074"
  "\157\142\152\145\143\164\040\143\154\141\163\163\075\042\107\164"
  "\153\105\156\164\162\171\042\040\151\144\075\042\144\157\155\141"
  "\151\156\137\145\156\164\162\171\042\076\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\166\151\163\151\142\154"
  "\145\042\076\124\162\165\145\074\057\160\162\157\160\145\162\164"
  "\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\143\141\156\137\146\157\143\165\163\042\076\124\162\165"
  "\145\074\057\160\162\157\160\145\162\164\171\076\074\160\162\157"
  "\160\145\162\164\171\040\156\141\155\145\075\042\164\157\157\154"
  "\164\151\160\137\164\145\170\164\042\040\164\162\141\156\163\154"
  "\141\164\141\142\154\145\075\042\171\145\163\042\076\101\160\160"
  "\145\156\144\040\164\150\145\040\144\157\155\141\151\156\040\156"
  "\141\155\145\040\046\154\164\073\144\157\155\141\151\156\046\147"
  "\164\073\040\164\157\040\164\150\145\040\154\157\143\141\154\040"
  "\150\157\163\164\040\156\141\155\145\040\146\157\162\040\141\165"
  "\164\150\145\156\164\151\143\141\164\151\157\156\040\160\165\162"
  "\160\157\163\145\163\056\012\143\157\156\146\151\147\072\040\144"
  "\157\155\141\151\156\040\046\154\164\073\144\157\155\141\151\156"
  "\046\147\164\073\074\057\160\162\157\160\145\162\164\171\076\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\150"
  "\145\170\160\141\156\144\042\076\124\162\165\145\074\057\160\162"
  "\157\160\145\162\164\171\076\074\057\157\142\152\145\143\164\076"
  "\074\160\141\143\153\151\156\147\076\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\154\145\146\164\137\141\164"
  "\164\141\143\150\042\076\061\074\057\160\162\157\160\145\162\164"
  "\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\164\157\160\137\141\164\164\141\143\150\042\076\066\074"
  "\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\167\151\144\164\150\042"
  "\076\061\074\057\160\162\157\160\145\162\164\171\076\074\057\160"
  "\141\143\153\151\156\147\076\074\057\143\150\151\154\144\076\074"
  "\143\150\151\154\144\076\074\157\142\152\145\143\164\040\143\154"
  "\141\163\163\075\042\107\164\153\102\165\164\164\157\156\042\040"
  "\151\144\075\042\141\144\166\141\156\143\145\144\137\142\165\164"
  "\164\157\156\042\076\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\166\151\163\151\142\154\145\042\076\124\162"
  "\165\145\074\057\160\162\157\160\145\162\164\171\076\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\143\141\156"
  "\137\146\157\143\165\163\042\076\124\162\165\145\074\057\160\162"
  "\157\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\162\145\143\145\151\166\145\163\137"
  "\144\145\146\141\165\154\164\042\076\106\141\154\163\145\074\057"
  "\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\150\141\154\151\147\156\042"
  "\076\145\156\144\074\057\160\162\157\160\145\162\164\171\076\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\166"
  "\141\154\151\147\156\042\076\145\156\144\074\057\160\162\157\160"
  "\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\155\141\162\147\151\156\137\164\157\160\042"
  "\076\063\062\074\057\160\162\157\160\145\162\164\171\076\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\150\145"
  "\170\160\141\156\144\042\076\124\162\165\145\074\057\160\162\157"
  "\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\166\145\170\160\141\156\144\042\076\124"
  "\162\165\145\074\057\160\162\157\160\145\162\164\171\076\074\143"
  "\150\151\154\144\076\074\157\142\152\145\143\164\040\143\154\141"
  "\163\163\075\042\107\164\153\102\157\170\042\040\151\144\075\042"
  "\150\142\157\170\062\042\076\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\166\151\163\151\142\154\145\042\076"
  "\124\162\165\145\074\057\160\162\157\160\145\162\164\171\076\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\143"
  "\141\156\137\146\157\143\165\163\042\076\106\141\154\163\145\074"
  "\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\163\160\141\143\151\156"
  "\147\042\076\066\074\057\160\162\157\160\145\162\164\171\076\074"
  "\143\150\151\154\144\076\074\157\142\152\145\143\164\040\143\154"
  "\141\163\163\075\042\107\164\153\111\155\141\147\145\042\040\151"
  "\144\075\042\151\155\141\147\145\061\042\076\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\166\151\163\151\142"
  "\154\145\042\076\124\162\165\145\074\057\160\162\157\160\145\162"
  "\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\143\141\156\137\146\157\143\165\163\042\076\106\141"
  "\154\163\145\074\057\160\162\157\160\145\162\164\171\076\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\151\143"
  "\157\156\137\156\141\155\145\042\076\160\162\145\146\145\162\145"
  "\156\143\145\163\055\163\171\163\164\145\155\055\163\171\155\142"
  "\157\154\151\143\074\057\160\162\157\160\145\162\164\171\076\074"
  "\057\157\142\152\145\143\164\076\074\160\141\143\153\151\156\147"
  "\076\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\145\170\160\141\156\144\042\076\106\141\154\163\145\074\057"
  "\160\162\157\160\145\162\164\171\076\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\146\151\154\154\042\076\106"
  "\141\154\163\145\074\057\160\162\157\160\145\162\164\171\076\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\160"
  "\157\163\151\164\151\157\156\042\076\060\074\057\160\162\157\160"
  "\145\162\164\171\076\074\057\160\141\143\153\151\156\147\076\074"
  "\057\143\150\151\154\144\076\074\143\150\151\154\144\076\074\157"
  "\142\152\145\143\164\040\143\154\141\163\163\075\042\107\164\153"
  "\114\141\142\145\154\042\040\151\144\075\042\154\141\142\145\154"
  "\061\042\076\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\166\151\163\151\142\154\145\042\076\124\162\165\145"
  "\074\057\160\162\157\160\145\162\164\171\076\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\143\141\156\137\146"
  "\157\143\165\163\042\076\106\141\154\163\145\074\057\160\162\157"
  "\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\154\141\142\145\154\042\040\164\162\141"
  "\156\163\154\141\164\141\142\154\145\075\042\171\145\163\042\076"
  "\101\144\166\141\156\143\145\137\144\342\200\246\074\057\160\162"
  "\157\160\145\162\164\171\076\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\165\163\145\137\165\156\144\145\162"
  "\154\151\156\145\042\076\124\162\165\145\074\057\160\162\157\160"
  "\145\162\164\171\076\074\057\157\142\152\145\143\164\076\074\160"
  "\141\143\153\151\156\147\076\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\145\170\160\141\156\144\042\076\106"
  "\141\154\163\145\074\057\160\162\157\160\145\162\164\171\076\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\146"
  "\151\154\154\042\076\124\162\165\145\074\057\160\162\157\160\145"
  "\162\164\171\076\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\160\157\163\151\164\151\157\156\042\076\061\074"
  "\057\160\162\157\160\145\162\164\171\076\074\057\160\141\143\153"
  "\151\156\147\076\074\057\143\150\151\154\144\076\074\057\157\142"
  "\152\145\143\164\076\074\057\143\150\151\154\144\076\074\057\157"
  "\142\152\145\143\164\076\074\160\141\143\153\151\156\147\076\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\154"
  "\145\146\164\137\141\164\164\141\143\150\042\076\060\074\057\160"
  "\162\157\160\145\162\164\171\076\074\160\162\157\160\145\162\164"
  "\171\040\156\141\155\145\075\042\164\157\160\137\141\164\164\141"
  "\143\150\042\076\067\074\057\160\162\157\160\145\162\164\171\076"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\167\151\144\164\150\042\076\062\074\057\160\162\157\160\145\162"
  "\164\171\076\074\057\160\141\143\153\151\156\147\076\074\057\143"
  "\150\151\154\144\076\074\057\157\142\152\145\143\164\076\074\057"
  "\151\156\164\145\162\146\141\143\145\076\012\000\000\050\165\165"
  "\141\171\051\156\145\164\167\157\162\153\055\155\141\156\141\147"
  "\145\162\055\160\160\164\160\057\002\000\000\000\146\162\145\145"
  "\144\145\163\153\164\157\160\057\003\000\000\000" };

static GStaticResource static_resource = { gresource_resource_data.data, sizeof (gresource_resource_data.data) - 1 /* nul terminator */, NULL, NULL, NULL };

G_GNUC_INTERNAL
GResource *gresource_get_resource (void);
GResource *gresource_get_resource (void)
{
  return g_static_resource_get_resource (&static_resource);
}
/* GLIB - Library of useful routines for C programming
 * Copyright (C) 1995-1997  Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 */

/*
 * Modified by the GLib Team and others 1997-2000.  See the AUTHORS
 * file for a list of people on the GLib Team.  See the ChangeLog
 * files for a list of changes.  These files are distributed with
 * GLib at ftp://ftp.gtk.org/pub/gtk/.
 */

#ifndef __G_CONSTRUCTOR_H__
#define __G_CONSTRUCTOR_H__

/*
  If G_HAS_CONSTRUCTORS is true then the compiler support *both* constructors and
  destructors, in a usable way, including e.g. on library unload. If not you're on
  your own.

  Some compilers need #pragma to handle this, which does not work with macros,
  so the way you need to use this is (for constructors):

  #ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
  #pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(my_constructor)
  #endif
  G_DEFINE_CONSTRUCTOR(my_constructor)
  static void my_constructor(void) {
   ...
  }

*/

#ifndef __GTK_DOC_IGNORE__

#if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR(_func) static void __attribute__((constructor)) _func (void);
#define G_DEFINE_DESTRUCTOR(_func) static void __attribute__((destructor)) _func (void);

#elif defined (_MSC_VER)

/*
 * Only try to include gslist.h if not already included via glib.h,
 * so that items using gconstructor.h outside of GLib (such as
 * GResources) continue to build properly.
 */
#ifndef __G_LIB_H__
#include "gslist.h"
#endif

#include <stdlib.h>

#define G_HAS_CONSTRUCTORS 1

/* We do some weird things to avoid the constructors being optimized
 * away on VS2015 if WholeProgramOptimization is enabled. First we
 * make a reference to the array from the wrapper to make sure its
 * references. Then we use a pragma to make sure the wrapper function
 * symbol is always included at the link stage. Also, the symbols
 * need to be extern (but not dllexport), even though they are not
 * really used from another object file.
 */

/* We need to account for differences between the mangling of symbols
 * for x86 and x64/ARM/ARM64 programs, as symbols on x86 are prefixed
 * with an underscore but symbols on x64/ARM/ARM64 are not.
 */
#ifdef _M_IX86
#define G_MSVC_SYMBOL_PREFIX "_"
#else
#define G_MSVC_SYMBOL_PREFIX ""
#endif

#define G_DEFINE_CONSTRUCTOR(_func) G_MSVC_CTOR (_func, G_MSVC_SYMBOL_PREFIX)
#define G_DEFINE_DESTRUCTOR(_func) G_MSVC_DTOR (_func, G_MSVC_SYMBOL_PREFIX)

#define G_MSVC_CTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _wrapper(void);              \
  int _func ## _wrapper(void) { _func(); g_slist_find (NULL,  _array ## _func); return 0; } \
  __pragma(comment(linker,"/include:" _sym_prefix # _func "_wrapper")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _wrapper;

#define G_MSVC_DTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _constructor(void);              \
  int _func ## _constructor(void) { atexit (_func); g_slist_find (NULL,  _array ## _func); return 0; } \
   __pragma(comment(linker,"/include:" _sym_prefix # _func "_constructor")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _constructor;

#elif defined(__SUNPRO_C)

/* This is not tested, but i believe it should work, based on:
 * http://opensource.apple.com/source/OpenSSL098/OpenSSL098-35/src/fips/fips_premain.c
 */

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  init(_func)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void);

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  fini(_func)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void);

#else

/* constructors not supported for this compiler */

#endif

#endif /* __GTK_DOC_IGNORE__ */
#endif /* __G_CONSTRUCTOR_H__ */

#ifdef G_HAS_CONSTRUCTORS

#ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(gresourceresource_constructor)
#endif
G_DEFINE_CONSTRUCTOR(gresourceresource_constructor)
#ifdef G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(gresourceresource_destructor)
#endif
G_DEFINE_DESTRUCTOR(gresourceresource_destructor)

#else
#warning "Constructor not supported on this compiler, linking in resources will not work"
#endif

static void gresourceresource_constructor (void)
{
  g_static_resource_init (&static_resource);
}

static void gresourceresource_destructor (void)
{
  g_static_resource_fini (&static_resource);
}
